==> gs1grader-0.1.2.tar.gz: gs1grader-0.1.2/src/gs1grader/graders/grid_non_uniformity_grader.py <==
from gs1grader.grader_interface import DataMatrixGraderInterface


class GridNonUniformityGrader(DataMatrixGraderInterface):
    """Grader for evaluating the grid non-uniformity of a Data Matrix code.

    Grid non-uniformity measures the deviation of the grid intersections
    from their ideal position. Lower grid non-uniformity values indicate more
    consistent and accurate grid positioning, which improves readability and
    scanning reliability.

    The grid non-uniformity grade is determined by the following thresholds:
    - Grade A: Less than or equal to 0.38
    - Grade B: 0.39 to 0.50
    - Grade C: 0.51 to 0.63
    - Grade D: 0.64 to 0.75
    - Grade F: Greater than 0.75
    """

    def __init__(self):
        """Initialize the GridNonUniformityGrader."""
        pass

    def compute_grade(self, decoded_data):
        """Compute grid non-uniformity grade for the given data
        matrix parameters.

        :param decoded_data: The decoded DataMatrix data containing
                            grid information
        :type decoded_data: DecodedDmtxData
        :returns: The grade of the grid non-uniformity (A, B, C, D, or F)
        :rtype: str
        """
        print("Checkout the advanced version to avail this grade")
        return None

    def explain_grade(self, data):
        """Explain the grid non-uniformity grade for the given data
        matrix parameters.

        :param data: Contains data matrix information and grade
        :type data: DecodedDmtxData
        :returns: Explanation of the grade
        :rtype: str
        """
        print("Checkout the advanced version to avail this grade")
        return None

==> gs1grader-0.1.5.tar.gz: gs1grader-0.1.5/src/gs1grader/graders/grid_non_uniformity_grader.py <==
from gs1grader.grader_interface import DataMatrixGraderInterface


class GridNonUniformityGrader(DataMatrixGraderInterface):
    """Grader for evaluating the grid non-uniformity of a Data Matrix code.

    Grid non-uniformity measures the deviation of the grid intersections
    from their ideal position. Lower grid non-uniformity values indicate more
    consistent and accurate grid positioning, which improves readability and
    scanning reliability.

    The grid non-uniformity grade is determined by the following thresholds:
    - Grade A: Less than or equal to 0.38
    - Grade B: 0.39 to 0.50
    - Grade C: 0.51 to 0.63
    - Grade D: 0.64 to 0.75
    - Grade F: Greater than 0.75
    """

    def __init__(self):
        """Initialize the GridNonUniformityGrader."""
        pass

    def compute_grade(self, decoded_data):
        """Compute grid non-uniformity grade for the given data
        matrix parameters.

        :param decoded_data: The decoded DataMatrix data containing
                            grid information
        :type decoded_data: DecodedDmtxData
        :returns: The grade of the grid non-uniformity (A, B, C, D, or F)
        :rtype: str
        """
        print("Checkout the advanced version to enable this grade")
        return None

    def explain_grade(self, data):
        """Explain the grid non-uniformity grade for the given data
        matrix parameters.

        :param data: Contains data matrix information and grade
        :type data: DecodedDmtxData
        :returns: Explanation of the grade
        :rtype: str
        """
        print("Checkout the advanced version to enable this grade")
        return None
